@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-use MyApp;
+use DirTreeTestApp;
 
-my $app = MyApp->new;
-$app->MainLoop;
\ No newline at end of file
+my $app = DirTreeTestApp->new;
+$app->MainLoop;
